@@ -619,10 +619,7 @@ var _ = Describe("Generating fluentd config", func() {
           retry_max_interval 60s
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-
-
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 
           overflow_action block
@@ -669,12 +666,8 @@ var _ = Describe("Generating fluentd config", func() {
           retry_max_interval 60s
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-
-
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-
           overflow_action block
         </buffer>
       </store>
@@ -721,7 +714,7 @@ var _ = Describe("Generating fluentd config", func() {
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 
 
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -771,7 +764,7 @@ var _ = Describe("Generating fluentd config", func() {
           retry_forever true
           queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
 
-          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+          total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 
 
           chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
@@ -1200,7 +1193,7 @@ var _ = Describe("Generating fluentd config", func() {
 					@type file
 					path '/var/lib/fluentd/secureforward_receiver'
 					queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-					total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+					total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 					chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
 					flush_mode interval
 					flush_interval 5s
@@ -1759,7 +1752,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
               queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-						  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+						  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -1806,7 +1799,7 @@ var _ = Describe("Generating fluentd config", func() {
  							retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -1854,7 +1847,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -1901,7 +1894,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -1949,7 +1942,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -1996,7 +1989,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -2044,7 +2037,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
@@ -2091,7 +2084,7 @@ var _ = Describe("Generating fluentd config", func() {
               retry_max_interval 60s
 							retry_forever true
 							queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
+							total_limit_size "#{ENV['TOTAL_LIMIT_SIZE_PER_BUFFER'] ||  8589934592 }" #8G
 							chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
 							overflow_action block
 						</buffer>
