@@ -699,16 +699,8 @@ tls_cert_path "{{$path}}"
   @type file
   path '{{.BufferPath}}'
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '1024' }"
-{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
-{{- else }}
-  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '1m'}"
-{{- end }}
   flush_mode {{.FlushMode}}
   flush_interval {{.FlushInterval}}
   flush_at_shutdown true
@@ -776,16 +768,8 @@ const storeElasticsearchTemplate = `{{ define "storeElasticsearch" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
-{{- else }}
-    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end}}
-{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -860,16 +844,8 @@ const storeSyslogTemplate = `{{- define "storeSyslog" -}}
     retry_max_interval {{.RetryMaxInterval}}
     retry_forever true
     queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
     total_limit_size {{.TotalLimitSize}}
-{{- else }}
-    total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
     chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-    chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
     overflow_action {{.OverflowAction}}
   </buffer>
 </store>
@@ -902,16 +878,8 @@ ssl_client_cert_key "#{File.exist?('{{ $tlsKey }}') ? '{{ $tlsKey }}' : nil}"
   retry_max_interval {{.RetryMaxInterval}}
   retry_forever true
   queued_chunks_limit_size "#{ENV['BUFFER_QUEUE_LIMIT'] || '32' }"
-{{- if .TotalLimitSize }}
   total_limit_size {{.TotalLimitSize}}
-{{- else }}
-  total_limit_size "#{ENV['TOTAL_LIMIT_SIZE'] ||  8589934592 }" #8G
-{{- end }}
-{{- if .ChunkLimitSize }}
   chunk_limit_size {{.ChunkLimitSize}}
-{{- else }}
-  chunk_limit_size "#{ENV['BUFFER_SIZE_LIMIT'] || '8m'}"
-{{- end }}
   overflow_action {{.OverflowAction}}
 </buffer>
 {{- end}}
